@@ -5,6 +5,7 @@ from .helpers.config import Config
 from .helpers.kafka_producer import Producer
 from .helpers.topics import Topics
 from .helpers.micro_fetcher import MicroFetcher
+from .helpers.atomic_transactions import Transactions
 
 __all__ = [
     "WeDeliverCore",
@@ -14,4 +15,5 @@ __all__ = [
     "init_logger",
     "Topics",
     "MicroFetcher",
+    "Transactions",
 ]
